@@ -1,4 +1,5 @@
 use crate::definitions::is_signing_field;
+use crate::hash_prefixes;
 
 use super::definitions::{get_field_code_and_type_code, get_transaction_type, is_serialized_field};
 use super::error::{Error, Result};
@@ -48,12 +49,12 @@ pub struct Serializer {
     output: Vec<u8>,
 }
 
-// This basic serializer supports only `to_string`.
-pub fn to_bytes<T>(value: &T) -> Result<Vec<u8>>
+pub fn to_bytes_with_opts<T>(value: &T, opts: Option<SerializerOptions>) -> Result<Vec<u8>>
 where
     T: Serialize,
 {
     let mut serializer = Serializer::default();
+    serializer.options = opts.unwrap_or_default();
     if let Some(prefix) = &serializer.options.prefix {
         serializer.output.append(&mut prefix.clone());
     }
@@ -72,30 +73,39 @@ where
     Ok(serializer.output)
 }
 
-// This basic serializer supports only `to_string`.
+pub fn to_bytes<T>(value: &T) -> Result<Vec<u8>>
+where
+    T: Serialize,
+{
+    to_bytes_with_opts(value, None)
+}
+
 pub fn to_bytes_for_signing<T>(value: &T) -> Result<Vec<u8>>
 where
     T: Serialize,
 {
-    let mut serializer = Serializer::default();
-    serializer.options.prefix = Some(crate::hash_prefixes::TRANSACTION_SIG.to_vec());
-    serializer.options.signing_fields_only = true;
-    if let Some(prefix) = &serializer.options.prefix {
-        serializer.output.append(&mut prefix.clone());
-    }
-    value.serialize(&mut serializer)?;
-    serializer
-        .fields
-        .sort_by(|a, b| a.0.partial_cmp(&b.0).unwrap());
-    for (header, value) in &mut serializer.fields {
-        serializer
-            .output
-            .append(&mut [header.to_bytes(), value.to_bytes()?.clone()].concat());
-    }
-    if let Some(suffix) = &serializer.options.suffix {
-        serializer.output.append(&mut suffix.clone());
-    }
-    Ok(serializer.output)
+    to_bytes_with_opts(
+        value,
+        Some(SerializerOptions {
+            prefix: Some(hash_prefixes::TRANSACTION_SIG.to_vec()),
+            signing_fields_only: true,
+            suffix: None,
+        }),
+    )
+}
+
+pub fn to_bytes_for_claim<T>(value: &T) -> Result<Vec<u8>>
+where
+    T: Serialize,
+{
+    to_bytes_with_opts(
+        value,
+        Some(SerializerOptions {
+            prefix: Some(hash_prefixes::PAYMENT_CHANNEL_CLAIM.to_vec()),
+            signing_fields_only: true,
+            suffix: None,
+        }),
+    )
 }
 
 impl<'a> ser::Serializer for &'a mut Serializer {
@@ -738,7 +748,6 @@ fn test_example() {
 
 #[cfg(test)]
 mod tests {
-    use crate::ser::to_bytes;
     use serde::Deserialize;
     use serde_json::Value;
     #[derive(Deserialize)]
